# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""SWIG wrapper for the CGAL Halfedge Data Structure package provided under the GPL-3.0+ license"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _CGAL_HalfedgeDS
else:
    import _CGAL_HalfedgeDS

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


import CGAL.CGAL_Kernel
RELATIVE_INDEXING = _CGAL_HalfedgeDS.RELATIVE_INDEXING
ABSOLUTE_INDEXING = _CGAL_HalfedgeDS.ABSOLUTE_INDEXING
class HDS_Halfedge_handle(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_HalfedgeDS.HDS_Halfedge_handle_swiginit(self, _CGAL_HalfedgeDS.new_HDS_Halfedge_handle())

    def opposite(self, *args):
        return _CGAL_HalfedgeDS.HDS_Halfedge_handle_opposite(self, *args)

    def next(self, *args):
        return _CGAL_HalfedgeDS.HDS_Halfedge_handle_next(self, *args)

    def set_next(self, c):
        return _CGAL_HalfedgeDS.HDS_Halfedge_handle_set_next(self, c)

    def is_border(self):
        return _CGAL_HalfedgeDS.HDS_Halfedge_handle_is_border(self)

    def prev(self, *args):
        return _CGAL_HalfedgeDS.HDS_Halfedge_handle_prev(self, *args)

    def set_prev(self, c):
        return _CGAL_HalfedgeDS.HDS_Halfedge_handle_set_prev(self, c)

    def vertex(self, *args):
        return _CGAL_HalfedgeDS.HDS_Halfedge_handle_vertex(self, *args)

    def set_vertex(self, c):
        return _CGAL_HalfedgeDS.HDS_Halfedge_handle_set_vertex(self, c)

    def face(self):
        return _CGAL_HalfedgeDS.HDS_Halfedge_handle_face(self)

    def set_face(self, c):
        return _CGAL_HalfedgeDS.HDS_Halfedge_handle_set_face(self, c)

    def deepcopy(self, *args):
        return _CGAL_HalfedgeDS.HDS_Halfedge_handle_deepcopy(self, *args)

    def __eq__(self, p):
        return _CGAL_HalfedgeDS.HDS_Halfedge_handle___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_HalfedgeDS.HDS_Halfedge_handle___ne__(self, p)

    def __hash__(self):
        return _CGAL_HalfedgeDS.HDS_Halfedge_handle___hash__(self)
    __swig_destroy__ = _CGAL_HalfedgeDS.delete_HDS_Halfedge_handle

# Register HDS_Halfedge_handle in _CGAL_HalfedgeDS:
_CGAL_HalfedgeDS.HDS_Halfedge_handle_swigregister(HDS_Halfedge_handle)

class HDS_Face_handle(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_HalfedgeDS.HDS_Face_handle_swiginit(self, _CGAL_HalfedgeDS.new_HDS_Face_handle())

    def halfedge(self, *args):
        return _CGAL_HalfedgeDS.HDS_Face_handle_halfedge(self, *args)

    def set_halfedge(self, c):
        return _CGAL_HalfedgeDS.HDS_Face_handle_set_halfedge(self, c)

    def deepcopy(self, *args):
        return _CGAL_HalfedgeDS.HDS_Face_handle_deepcopy(self, *args)

    def __eq__(self, p):
        return _CGAL_HalfedgeDS.HDS_Face_handle___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_HalfedgeDS.HDS_Face_handle___ne__(self, p)

    def __hash__(self):
        return _CGAL_HalfedgeDS.HDS_Face_handle___hash__(self)
    __swig_destroy__ = _CGAL_HalfedgeDS.delete_HDS_Face_handle

# Register HDS_Face_handle in _CGAL_HalfedgeDS:
_CGAL_HalfedgeDS.HDS_Face_handle_swigregister(HDS_Face_handle)

class HDS_Vertex_handle(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_HalfedgeDS.HDS_Vertex_handle_swiginit(self, _CGAL_HalfedgeDS.new_HDS_Vertex_handle())

    def halfedge(self, *args):
        return _CGAL_HalfedgeDS.HDS_Vertex_handle_halfedge(self, *args)

    def set_halfedge(self, c):
        return _CGAL_HalfedgeDS.HDS_Vertex_handle_set_halfedge(self, c)

    def point(self, *args):
        return _CGAL_HalfedgeDS.HDS_Vertex_handle_point(self, *args)

    def set_point(self, p):
        return _CGAL_HalfedgeDS.HDS_Vertex_handle_set_point(self, p)

    def deepcopy(self, *args):
        return _CGAL_HalfedgeDS.HDS_Vertex_handle_deepcopy(self, *args)

    def __eq__(self, p):
        return _CGAL_HalfedgeDS.HDS_Vertex_handle___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_HalfedgeDS.HDS_Vertex_handle___ne__(self, p)

    def __hash__(self):
        return _CGAL_HalfedgeDS.HDS_Vertex_handle___hash__(self)
    __swig_destroy__ = _CGAL_HalfedgeDS.delete_HDS_Vertex_handle

# Register HDS_Vertex_handle in _CGAL_HalfedgeDS:
_CGAL_HalfedgeDS.HDS_Vertex_handle_swigregister(HDS_Vertex_handle)

class HDS_Vertex_iterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_HalfedgeDS.HDS_Vertex_iterator_swiginit(self, _CGAL_HalfedgeDS.new_HDS_Vertex_iterator())

    def __iter__(self):
        return _CGAL_HalfedgeDS.HDS_Vertex_iterator___iter__(self)

    def __next__(self):
        return _CGAL_HalfedgeDS.HDS_Vertex_iterator___next__(self)

    def next(self, *args):
        return _CGAL_HalfedgeDS.HDS_Vertex_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_HalfedgeDS.HDS_Vertex_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_HalfedgeDS.HDS_Vertex_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_HalfedgeDS.HDS_Vertex_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_HalfedgeDS.HDS_Vertex_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_HalfedgeDS.delete_HDS_Vertex_iterator

# Register HDS_Vertex_iterator in _CGAL_HalfedgeDS:
_CGAL_HalfedgeDS.HDS_Vertex_iterator_swigregister(HDS_Vertex_iterator)

class HDS_Halfedge_iterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_HalfedgeDS.HDS_Halfedge_iterator_swiginit(self, _CGAL_HalfedgeDS.new_HDS_Halfedge_iterator())

    def __iter__(self):
        return _CGAL_HalfedgeDS.HDS_Halfedge_iterator___iter__(self)

    def __next__(self):
        return _CGAL_HalfedgeDS.HDS_Halfedge_iterator___next__(self)

    def next(self, *args):
        return _CGAL_HalfedgeDS.HDS_Halfedge_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_HalfedgeDS.HDS_Halfedge_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_HalfedgeDS.HDS_Halfedge_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_HalfedgeDS.HDS_Halfedge_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_HalfedgeDS.HDS_Halfedge_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_HalfedgeDS.delete_HDS_Halfedge_iterator

# Register HDS_Halfedge_iterator in _CGAL_HalfedgeDS:
_CGAL_HalfedgeDS.HDS_Halfedge_iterator_swigregister(HDS_Halfedge_iterator)

class HDS_Face_iterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_HalfedgeDS.HDS_Face_iterator_swiginit(self, _CGAL_HalfedgeDS.new_HDS_Face_iterator())

    def __iter__(self):
        return _CGAL_HalfedgeDS.HDS_Face_iterator___iter__(self)

    def __next__(self):
        return _CGAL_HalfedgeDS.HDS_Face_iterator___next__(self)

    def next(self, *args):
        return _CGAL_HalfedgeDS.HDS_Face_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_HalfedgeDS.HDS_Face_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_HalfedgeDS.HDS_Face_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_HalfedgeDS.HDS_Face_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_HalfedgeDS.HDS_Face_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_HalfedgeDS.delete_HDS_Face_iterator

# Register HDS_Face_iterator in _CGAL_HalfedgeDS:
_CGAL_HalfedgeDS.HDS_Face_iterator_swigregister(HDS_Face_iterator)

class HalfedgeDS_modifier(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_HalfedgeDS.HalfedgeDS_modifier_swiginit(self, _CGAL_HalfedgeDS.new_HalfedgeDS_modifier())

    def begin_surface(self, v, f, h=0, mode=RELATIVE_INDEXING):
        return _CGAL_HalfedgeDS.HalfedgeDS_modifier_begin_surface(self, v, f, h, mode)

    def end_surface(self):
        return _CGAL_HalfedgeDS.HalfedgeDS_modifier_end_surface(self)

    def add_vertex(self, p):
        return _CGAL_HalfedgeDS.HalfedgeDS_modifier_add_vertex(self, p)

    def begin_facet(self):
        return _CGAL_HalfedgeDS.HalfedgeDS_modifier_begin_facet(self)

    def end_facet(self):
        return _CGAL_HalfedgeDS.HalfedgeDS_modifier_end_facet(self)

    def add_vertex_to_facet(self, i):
        return _CGAL_HalfedgeDS.HalfedgeDS_modifier_add_vertex_to_facet(self, i)

    def rollback(self):
        return _CGAL_HalfedgeDS.HalfedgeDS_modifier_rollback(self)

    def clear(self):
        return _CGAL_HalfedgeDS.HalfedgeDS_modifier_clear(self)
    __swig_destroy__ = _CGAL_HalfedgeDS.delete_HalfedgeDS_modifier

# Register HalfedgeDS_modifier in _CGAL_HalfedgeDS:
_CGAL_HalfedgeDS.HalfedgeDS_modifier_swigregister(HalfedgeDS_modifier)

class HalfedgeDS(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_HalfedgeDS.HalfedgeDS_swiginit(self, _CGAL_HalfedgeDS.new_HalfedgeDS(*args))

    def reserve(self, c1, c2, c3):
        return _CGAL_HalfedgeDS.HalfedgeDS_reserve(self, c1, c2, c3)

    def size_of_vertices(self):
        return _CGAL_HalfedgeDS.HalfedgeDS_size_of_vertices(self)

    def size_of_halfedges(self):
        return _CGAL_HalfedgeDS.HalfedgeDS_size_of_halfedges(self)

    def size_of_faces(self):
        return _CGAL_HalfedgeDS.HalfedgeDS_size_of_faces(self)

    def capacity_of_vertices(self):
        return _CGAL_HalfedgeDS.HalfedgeDS_capacity_of_vertices(self)

    def capacity_of_halfedges(self):
        return _CGAL_HalfedgeDS.HalfedgeDS_capacity_of_halfedges(self)

    def capacity_of_faces(self):
        return _CGAL_HalfedgeDS.HalfedgeDS_capacity_of_faces(self)

    def bytes(self):
        return _CGAL_HalfedgeDS.HalfedgeDS_bytes(self)

    def bytes_reserved(self):
        return _CGAL_HalfedgeDS.HalfedgeDS_bytes_reserved(self)

    def vertices(self):
        return _CGAL_HalfedgeDS.HalfedgeDS_vertices(self)

    def halfedges(self):
        return _CGAL_HalfedgeDS.HalfedgeDS_halfedges(self)

    def faces(self):
        return _CGAL_HalfedgeDS.HalfedgeDS_faces(self)

    def vertices_push_back(self, *args):
        return _CGAL_HalfedgeDS.HalfedgeDS_vertices_push_back(self, *args)

    def edges_push_back(self):
        return _CGAL_HalfedgeDS.HalfedgeDS_edges_push_back(self)

    def faces_push_back(self):
        return _CGAL_HalfedgeDS.HalfedgeDS_faces_push_back(self)

    def vertices_pop_front(self):
        return _CGAL_HalfedgeDS.HalfedgeDS_vertices_pop_front(self)

    def vertices_pop_back(self):
        return _CGAL_HalfedgeDS.HalfedgeDS_vertices_pop_back(self)

    def vertices_erase(self, *args):
        return _CGAL_HalfedgeDS.HalfedgeDS_vertices_erase(self, *args)

    def edges_pop_front(self):
        return _CGAL_HalfedgeDS.HalfedgeDS_edges_pop_front(self)

    def edges_pop_back(self):
        return _CGAL_HalfedgeDS.HalfedgeDS_edges_pop_back(self)

    def edges_erase(self, *args):
        return _CGAL_HalfedgeDS.HalfedgeDS_edges_erase(self, *args)

    def faces_pop_front(self):
        return _CGAL_HalfedgeDS.HalfedgeDS_faces_pop_front(self)

    def faces_pop_back(self):
        return _CGAL_HalfedgeDS.HalfedgeDS_faces_pop_back(self)

    def faces_erase(self, *args):
        return _CGAL_HalfedgeDS.HalfedgeDS_faces_erase(self, *args)

    def vertices_clear(self):
        return _CGAL_HalfedgeDS.HalfedgeDS_vertices_clear(self)

    def edges_clear(self):
        return _CGAL_HalfedgeDS.HalfedgeDS_edges_clear(self)

    def faces_clear(self):
        return _CGAL_HalfedgeDS.HalfedgeDS_faces_clear(self)

    def clear(self):
        return _CGAL_HalfedgeDS.HalfedgeDS_clear(self)

    def normalize_border(self):
        return _CGAL_HalfedgeDS.HalfedgeDS_normalize_border(self)

    def size_of_border_halfedges(self):
        return _CGAL_HalfedgeDS.HalfedgeDS_size_of_border_halfedges(self)

    def size_of_border_edges(self):
        return _CGAL_HalfedgeDS.HalfedgeDS_size_of_border_edges(self)

    def border_halfedges(self):
        return _CGAL_HalfedgeDS.HalfedgeDS_border_halfedges(self)

    def deepcopy(self, *args):
        return _CGAL_HalfedgeDS.HalfedgeDS_deepcopy(self, *args)

    def delegate(self, modifier):
        return _CGAL_HalfedgeDS.HalfedgeDS_delegate(self, modifier)
    __swig_destroy__ = _CGAL_HalfedgeDS.delete_HalfedgeDS

# Register HalfedgeDS in _CGAL_HalfedgeDS:
_CGAL_HalfedgeDS.HalfedgeDS_swigregister(HalfedgeDS)

class HalfedgeDS_decorator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, hds):
        _CGAL_HalfedgeDS.HalfedgeDS_decorator_swiginit(self, _CGAL_HalfedgeDS.new_HalfedgeDS_decorator(hds))

    def vertices_push_back(self, *args):
        return _CGAL_HalfedgeDS.HalfedgeDS_decorator_vertices_push_back(self, *args)

    def faces_push_back(self):
        return _CGAL_HalfedgeDS.HalfedgeDS_decorator_faces_push_back(self)

    def create_loop(self):
        return _CGAL_HalfedgeDS.HalfedgeDS_decorator_create_loop(self)

    def create_segment(self):
        return _CGAL_HalfedgeDS.HalfedgeDS_decorator_create_segment(self)

    def vertices_pop_front(self):
        return _CGAL_HalfedgeDS.HalfedgeDS_decorator_vertices_pop_front(self)

    def vertices_pop_back(self):
        return _CGAL_HalfedgeDS.HalfedgeDS_decorator_vertices_pop_back(self)

    def vertices_erase(self, *args):
        return _CGAL_HalfedgeDS.HalfedgeDS_decorator_vertices_erase(self, *args)

    def faces_pop_front(self):
        return _CGAL_HalfedgeDS.HalfedgeDS_decorator_faces_pop_front(self)

    def faces_pop_back(self):
        return _CGAL_HalfedgeDS.HalfedgeDS_decorator_faces_pop_back(self)

    def faces_erase(self, *args):
        return _CGAL_HalfedgeDS.HalfedgeDS_decorator_faces_erase(self, *args)

    def erase_face(self, c):
        return _CGAL_HalfedgeDS.HalfedgeDS_decorator_erase_face(self, c)

    def erase_connected_component(self, c):
        return _CGAL_HalfedgeDS.HalfedgeDS_decorator_erase_connected_component(self, c)

    def keep_largest_connected_components(self, c):
        return _CGAL_HalfedgeDS.HalfedgeDS_decorator_keep_largest_connected_components(self, c)

    def make_hole(self, c):
        return _CGAL_HalfedgeDS.HalfedgeDS_decorator_make_hole(self, c)

    def fill_hole(self, c):
        return _CGAL_HalfedgeDS.HalfedgeDS_decorator_fill_hole(self, c)

    def add_face_to_border(self, c1, c2):
        return _CGAL_HalfedgeDS.HalfedgeDS_decorator_add_face_to_border(self, c1, c2)

    def split_face(self, *args):
        return _CGAL_HalfedgeDS.HalfedgeDS_decorator_split_face(self, *args)

    def join_face(self, *args):
        return _CGAL_HalfedgeDS.HalfedgeDS_decorator_join_face(self, *args)

    def split_vertex(self, *args):
        return _CGAL_HalfedgeDS.HalfedgeDS_decorator_split_vertex(self, *args)

    def join_vertex(self, *args):
        return _CGAL_HalfedgeDS.HalfedgeDS_decorator_join_vertex(self, *args)

    def create_center_vertex(self, *args):
        return _CGAL_HalfedgeDS.HalfedgeDS_decorator_create_center_vertex(self, *args)

    def erase_center_vertex(self, *args):
        return _CGAL_HalfedgeDS.HalfedgeDS_decorator_erase_center_vertex(self, *args)

    def split_loop(self, *args):
        return _CGAL_HalfedgeDS.HalfedgeDS_decorator_split_loop(self, *args)

    def join_loop(self, *args):
        return _CGAL_HalfedgeDS.HalfedgeDS_decorator_join_loop(self, *args)

    def is_valid(self, *args):
        return _CGAL_HalfedgeDS.HalfedgeDS_decorator_is_valid(self, *args)

    def normalized_border_is_valid(self, *args):
        return _CGAL_HalfedgeDS.HalfedgeDS_decorator_normalized_border_is_valid(self, *args)

    def inside_out(self):
        return _CGAL_HalfedgeDS.HalfedgeDS_decorator_inside_out(self)
    __swig_destroy__ = _CGAL_HalfedgeDS.delete_HalfedgeDS_decorator

# Register HalfedgeDS_decorator in _CGAL_HalfedgeDS:
_CGAL_HalfedgeDS.HalfedgeDS_decorator_swigregister(HalfedgeDS_decorator)






# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""SWIG wrapper for the CGAL 3D Fast Intersection and Distance Computation package provided under the GPL-3.0+ license"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _CGAL_AABB_tree
else:
    import _CGAL_AABB_tree

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


import CGAL.CGAL_Kernel
import CGAL.CGAL_Polyhedron_3
class Object(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_AABB_tree.Object_swiginit(self, _CGAL_AABB_tree.new_Object())

    def is_Point_2(self):
        return _CGAL_AABB_tree.Object_is_Point_2(self)

    def get_Point_2(self):
        return _CGAL_AABB_tree.Object_get_Point_2(self)

    def is_Point_3(self):
        return _CGAL_AABB_tree.Object_is_Point_3(self)

    def get_Point_3(self):
        return _CGAL_AABB_tree.Object_get_Point_3(self)

    def is_Triangle_2(self):
        return _CGAL_AABB_tree.Object_is_Triangle_2(self)

    def get_Triangle_2(self):
        return _CGAL_AABB_tree.Object_get_Triangle_2(self)

    def is_Triangle_3(self):
        return _CGAL_AABB_tree.Object_is_Triangle_3(self)

    def get_Triangle_3(self):
        return _CGAL_AABB_tree.Object_get_Triangle_3(self)

    def is_Segment_3(self):
        return _CGAL_AABB_tree.Object_is_Segment_3(self)

    def get_Segment_3(self):
        return _CGAL_AABB_tree.Object_get_Segment_3(self)

    def is_Segment_2(self):
        return _CGAL_AABB_tree.Object_is_Segment_2(self)

    def get_Segment_2(self):
        return _CGAL_AABB_tree.Object_get_Segment_2(self)

    def is_Line_3(self):
        return _CGAL_AABB_tree.Object_is_Line_3(self)

    def get_Line_3(self):
        return _CGAL_AABB_tree.Object_get_Line_3(self)

    def is_Line_2(self):
        return _CGAL_AABB_tree.Object_is_Line_2(self)

    def get_Line_2(self):
        return _CGAL_AABB_tree.Object_get_Line_2(self)

    def is_Plane_3(self):
        return _CGAL_AABB_tree.Object_is_Plane_3(self)

    def get_Plane_3(self):
        return _CGAL_AABB_tree.Object_get_Plane_3(self)

    def is_Ray_2(self):
        return _CGAL_AABB_tree.Object_is_Ray_2(self)

    def get_Ray_2(self):
        return _CGAL_AABB_tree.Object_get_Ray_2(self)

    def is_Ray_3(self):
        return _CGAL_AABB_tree.Object_is_Ray_3(self)

    def get_Ray_3(self):
        return _CGAL_AABB_tree.Object_get_Ray_3(self)

    def is_Polygon_2(self):
        return _CGAL_AABB_tree.Object_is_Polygon_2(self)

    def get_Polygon_2(self):
        return _CGAL_AABB_tree.Object_get_Polygon_2(self)

    def empty(self):
        return _CGAL_AABB_tree.Object_empty(self)
    __swig_destroy__ = _CGAL_AABB_tree.delete_Object

# Register Object in _CGAL_AABB_tree:
_CGAL_AABB_tree.Object_swigregister(Object)

class Point_and_Polyhedron_3_Facet_handle(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_AABB_tree.Point_and_Polyhedron_3_Facet_handle_swiginit(self, _CGAL_AABB_tree.new_Point_and_Polyhedron_3_Facet_handle(*args))
    first = property(_CGAL_AABB_tree.Point_and_Polyhedron_3_Facet_handle_first_get, _CGAL_AABB_tree.Point_and_Polyhedron_3_Facet_handle_first_set)
    second = property(_CGAL_AABB_tree.Point_and_Polyhedron_3_Facet_handle_second_get, _CGAL_AABB_tree.Point_and_Polyhedron_3_Facet_handle_second_set)
    def __len__(self):
        return 2
    def __repr__(self):
        return str((self.first, self.second))
    def __getitem__(self, index): 
        if not (index % 2):
            return self.first
        else:
            return self.second
    def __setitem__(self, index, val):
        if not (index % 2):
            self.first = val
        else:
            self.second = val
    __swig_destroy__ = _CGAL_AABB_tree.delete_Point_and_Polyhedron_3_Facet_handle

# Register Point_and_Polyhedron_3_Facet_handle in _CGAL_AABB_tree:
_CGAL_AABB_tree.Point_and_Polyhedron_3_Facet_handle_swigregister(Point_and_Polyhedron_3_Facet_handle)

class Point_and_Polyhedron_3_Halfedge_handle(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_AABB_tree.Point_and_Polyhedron_3_Halfedge_handle_swiginit(self, _CGAL_AABB_tree.new_Point_and_Polyhedron_3_Halfedge_handle(*args))
    first = property(_CGAL_AABB_tree.Point_and_Polyhedron_3_Halfedge_handle_first_get, _CGAL_AABB_tree.Point_and_Polyhedron_3_Halfedge_handle_first_set)
    second = property(_CGAL_AABB_tree.Point_and_Polyhedron_3_Halfedge_handle_second_get, _CGAL_AABB_tree.Point_and_Polyhedron_3_Halfedge_handle_second_set)
    def __len__(self):
        return 2
    def __repr__(self):
        return str((self.first, self.second))
    def __getitem__(self, index): 
        if not (index % 2):
            return self.first
        else:
            return self.second
    def __setitem__(self, index, val):
        if not (index % 2):
            self.first = val
        else:
            self.second = val
    __swig_destroy__ = _CGAL_AABB_tree.delete_Point_and_Polyhedron_3_Halfedge_handle

# Register Point_and_Polyhedron_3_Halfedge_handle in _CGAL_AABB_tree:
_CGAL_AABB_tree.Point_and_Polyhedron_3_Halfedge_handle_swigregister(Point_and_Polyhedron_3_Halfedge_handle)

class Point_and_Integer(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_AABB_tree.Point_and_Integer_swiginit(self, _CGAL_AABB_tree.new_Point_and_Integer(*args))
    first = property(_CGAL_AABB_tree.Point_and_Integer_first_get, _CGAL_AABB_tree.Point_and_Integer_first_set)
    second = property(_CGAL_AABB_tree.Point_and_Integer_second_get, _CGAL_AABB_tree.Point_and_Integer_second_set)
    def __len__(self):
        return 2
    def __repr__(self):
        return str((self.first, self.second))
    def __getitem__(self, index): 
        if not (index % 2):
            return self.first
        else:
            return self.second
    def __setitem__(self, index, val):
        if not (index % 2):
            self.first = val
        else:
            self.second = val
    __swig_destroy__ = _CGAL_AABB_tree.delete_Point_and_Integer

# Register Point_and_Integer in _CGAL_AABB_tree:
_CGAL_AABB_tree.Point_and_Integer_swigregister(Point_and_Integer)

class Object_and_Polyhedron_3_Facet_handle(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_AABB_tree.Object_and_Polyhedron_3_Facet_handle_swiginit(self, _CGAL_AABB_tree.new_Object_and_Polyhedron_3_Facet_handle(*args))
    first = property(_CGAL_AABB_tree.Object_and_Polyhedron_3_Facet_handle_first_get, _CGAL_AABB_tree.Object_and_Polyhedron_3_Facet_handle_first_set)
    second = property(_CGAL_AABB_tree.Object_and_Polyhedron_3_Facet_handle_second_get, _CGAL_AABB_tree.Object_and_Polyhedron_3_Facet_handle_second_set)
    def __len__(self):
        return 2
    def __repr__(self):
        return str((self.first, self.second))
    def __getitem__(self, index): 
        if not (index % 2):
            return self.first
        else:
            return self.second
    def __setitem__(self, index, val):
        if not (index % 2):
            self.first = val
        else:
            self.second = val
    __swig_destroy__ = _CGAL_AABB_tree.delete_Object_and_Polyhedron_3_Facet_handle

# Register Object_and_Polyhedron_3_Facet_handle in _CGAL_AABB_tree:
_CGAL_AABB_tree.Object_and_Polyhedron_3_Facet_handle_swigregister(Object_and_Polyhedron_3_Facet_handle)

class Object_and_Polyhedron_3_Halfedge_handle(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_AABB_tree.Object_and_Polyhedron_3_Halfedge_handle_swiginit(self, _CGAL_AABB_tree.new_Object_and_Polyhedron_3_Halfedge_handle(*args))
    first = property(_CGAL_AABB_tree.Object_and_Polyhedron_3_Halfedge_handle_first_get, _CGAL_AABB_tree.Object_and_Polyhedron_3_Halfedge_handle_first_set)
    second = property(_CGAL_AABB_tree.Object_and_Polyhedron_3_Halfedge_handle_second_get, _CGAL_AABB_tree.Object_and_Polyhedron_3_Halfedge_handle_second_set)
    def __len__(self):
        return 2
    def __repr__(self):
        return str((self.first, self.second))
    def __getitem__(self, index): 
        if not (index % 2):
            return self.first
        else:
            return self.second
    def __setitem__(self, index, val):
        if not (index % 2):
            self.first = val
        else:
            self.second = val
    __swig_destroy__ = _CGAL_AABB_tree.delete_Object_and_Polyhedron_3_Halfedge_handle

# Register Object_and_Polyhedron_3_Halfedge_handle in _CGAL_AABB_tree:
_CGAL_AABB_tree.Object_and_Polyhedron_3_Halfedge_handle_swigregister(Object_and_Polyhedron_3_Halfedge_handle)

class Object_and_Integer(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_AABB_tree.Object_and_Integer_swiginit(self, _CGAL_AABB_tree.new_Object_and_Integer(*args))
    first = property(_CGAL_AABB_tree.Object_and_Integer_first_get, _CGAL_AABB_tree.Object_and_Integer_first_set)
    second = property(_CGAL_AABB_tree.Object_and_Integer_second_get, _CGAL_AABB_tree.Object_and_Integer_second_set)
    def __len__(self):
        return 2
    def __repr__(self):
        return str((self.first, self.second))
    def __getitem__(self, index): 
        if not (index % 2):
            return self.first
        else:
            return self.second
    def __setitem__(self, index, val):
        if not (index % 2):
            self.first = val
        else:
            self.second = val
    __swig_destroy__ = _CGAL_AABB_tree.delete_Object_and_Integer

# Register Object_and_Integer in _CGAL_AABB_tree:
_CGAL_AABB_tree.Object_and_Integer_swigregister(Object_and_Integer)

class Optional_Polyhedron_3_Halfedge_handle(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_AABB_tree.Optional_Polyhedron_3_Halfedge_handle_swiginit(self, _CGAL_AABB_tree.new_Optional_Polyhedron_3_Halfedge_handle())

    def empty(self):
        return _CGAL_AABB_tree.Optional_Polyhedron_3_Halfedge_handle_empty(self)

    def value(self):
        return _CGAL_AABB_tree.Optional_Polyhedron_3_Halfedge_handle_value(self)

    def deepcopy(self, *args):
        return _CGAL_AABB_tree.Optional_Polyhedron_3_Halfedge_handle_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_AABB_tree.delete_Optional_Polyhedron_3_Halfedge_handle

# Register Optional_Polyhedron_3_Halfedge_handle in _CGAL_AABB_tree:
_CGAL_AABB_tree.Optional_Polyhedron_3_Halfedge_handle_swigregister(Optional_Polyhedron_3_Halfedge_handle)

class Optional_Polyhedron_3_Facet_handle(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_AABB_tree.Optional_Polyhedron_3_Facet_handle_swiginit(self, _CGAL_AABB_tree.new_Optional_Polyhedron_3_Facet_handle())

    def empty(self):
        return _CGAL_AABB_tree.Optional_Polyhedron_3_Facet_handle_empty(self)

    def value(self):
        return _CGAL_AABB_tree.Optional_Polyhedron_3_Facet_handle_value(self)

    def deepcopy(self, *args):
        return _CGAL_AABB_tree.Optional_Polyhedron_3_Facet_handle_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_AABB_tree.delete_Optional_Polyhedron_3_Facet_handle

# Register Optional_Polyhedron_3_Facet_handle in _CGAL_AABB_tree:
_CGAL_AABB_tree.Optional_Polyhedron_3_Facet_handle_swigregister(Optional_Polyhedron_3_Facet_handle)

class Optional_Integer(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_AABB_tree.Optional_Integer_swiginit(self, _CGAL_AABB_tree.new_Optional_Integer())

    def empty(self):
        return _CGAL_AABB_tree.Optional_Integer_empty(self)

    def value(self):
        return _CGAL_AABB_tree.Optional_Integer_value(self)

    def deepcopy(self, *args):
        return _CGAL_AABB_tree.Optional_Integer_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_AABB_tree.delete_Optional_Integer

# Register Optional_Integer in _CGAL_AABB_tree:
_CGAL_AABB_tree.Optional_Integer_swigregister(Optional_Integer)

class Optional_Object_and_Polyhedron_3_Halfedge_handle(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_AABB_tree.Optional_Object_and_Polyhedron_3_Halfedge_handle_swiginit(self, _CGAL_AABB_tree.new_Optional_Object_and_Polyhedron_3_Halfedge_handle())

    def empty(self):
        return _CGAL_AABB_tree.Optional_Object_and_Polyhedron_3_Halfedge_handle_empty(self)

    def value(self):
        return _CGAL_AABB_tree.Optional_Object_and_Polyhedron_3_Halfedge_handle_value(self)

    def deepcopy(self, *args):
        return _CGAL_AABB_tree.Optional_Object_and_Polyhedron_3_Halfedge_handle_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_AABB_tree.delete_Optional_Object_and_Polyhedron_3_Halfedge_handle

# Register Optional_Object_and_Polyhedron_3_Halfedge_handle in _CGAL_AABB_tree:
_CGAL_AABB_tree.Optional_Object_and_Polyhedron_3_Halfedge_handle_swigregister(Optional_Object_and_Polyhedron_3_Halfedge_handle)

class Optional_Object_and_Polyhedron_3_Facet_handle(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_AABB_tree.Optional_Object_and_Polyhedron_3_Facet_handle_swiginit(self, _CGAL_AABB_tree.new_Optional_Object_and_Polyhedron_3_Facet_handle())

    def empty(self):
        return _CGAL_AABB_tree.Optional_Object_and_Polyhedron_3_Facet_handle_empty(self)

    def value(self):
        return _CGAL_AABB_tree.Optional_Object_and_Polyhedron_3_Facet_handle_value(self)

    def deepcopy(self, *args):
        return _CGAL_AABB_tree.Optional_Object_and_Polyhedron_3_Facet_handle_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_AABB_tree.delete_Optional_Object_and_Polyhedron_3_Facet_handle

# Register Optional_Object_and_Polyhedron_3_Facet_handle in _CGAL_AABB_tree:
_CGAL_AABB_tree.Optional_Object_and_Polyhedron_3_Facet_handle_swigregister(Optional_Object_and_Polyhedron_3_Facet_handle)

class Optional_Object_and_Integer(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_AABB_tree.Optional_Object_and_Integer_swiginit(self, _CGAL_AABB_tree.new_Optional_Object_and_Integer())

    def empty(self):
        return _CGAL_AABB_tree.Optional_Object_and_Integer_empty(self)

    def value(self):
        return _CGAL_AABB_tree.Optional_Object_and_Integer_value(self)

    def deepcopy(self, *args):
        return _CGAL_AABB_tree.Optional_Object_and_Integer_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_AABB_tree.delete_Optional_Object_and_Integer

# Register Optional_Object_and_Integer in _CGAL_AABB_tree:
_CGAL_AABB_tree.Optional_Object_and_Integer_swigregister(Optional_Object_and_Integer)

class AABB_tree_Polyhedron_3_Facet_handle(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Facet_handle_swiginit(self, _CGAL_AABB_tree.new_AABB_tree_Polyhedron_3_Facet_handle(*args))

    def rebuild(self, range):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Facet_handle_rebuild(self, range)

    def clear(self):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Facet_handle_clear(self)

    def size(self):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Facet_handle_size(self)

    def empty(self):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Facet_handle_empty(self)

    def do_intersect(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Facet_handle_do_intersect(self, *args)

    def number_of_intersected_primitives(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Facet_handle_number_of_intersected_primitives(self, *args)

    def all_intersected_primitives(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Facet_handle_all_intersected_primitives(self, *args)

    def any_intersected_primitive(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Facet_handle_any_intersected_primitive(self, *args)

    def any_intersection(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Facet_handle_any_intersection(self, *args)

    def all_intersections(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Facet_handle_all_intersections(self, *args)

    def squared_distance(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Facet_handle_squared_distance(self, *args)

    def closest_point(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Facet_handle_closest_point(self, *args)

    def closest_point_and_primitive(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Facet_handle_closest_point_and_primitive(self, *args)

    def accelerate_distance_queries(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Facet_handle_accelerate_distance_queries(self, *args)
    __swig_destroy__ = _CGAL_AABB_tree.delete_AABB_tree_Polyhedron_3_Facet_handle

# Register AABB_tree_Polyhedron_3_Facet_handle in _CGAL_AABB_tree:
_CGAL_AABB_tree.AABB_tree_Polyhedron_3_Facet_handle_swigregister(AABB_tree_Polyhedron_3_Facet_handle)

class AABB_tree_Polyhedron_3_Halfedge_handle(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Halfedge_handle_swiginit(self, _CGAL_AABB_tree.new_AABB_tree_Polyhedron_3_Halfedge_handle(*args))

    def rebuild(self, range):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Halfedge_handle_rebuild(self, range)

    def clear(self):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Halfedge_handle_clear(self)

    def size(self):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Halfedge_handle_size(self)

    def empty(self):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Halfedge_handle_empty(self)

    def do_intersect(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Halfedge_handle_do_intersect(self, *args)

    def number_of_intersected_primitives(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Halfedge_handle_number_of_intersected_primitives(self, *args)

    def all_intersected_primitives(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Halfedge_handle_all_intersected_primitives(self, *args)

    def any_intersected_primitive(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Halfedge_handle_any_intersected_primitive(self, *args)

    def any_intersection(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Halfedge_handle_any_intersection(self, *args)

    def all_intersections(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Halfedge_handle_all_intersections(self, *args)

    def squared_distance(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Halfedge_handle_squared_distance(self, *args)

    def closest_point(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Halfedge_handle_closest_point(self, *args)

    def closest_point_and_primitive(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Halfedge_handle_closest_point_and_primitive(self, *args)

    def accelerate_distance_queries(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Halfedge_handle_accelerate_distance_queries(self, *args)
    __swig_destroy__ = _CGAL_AABB_tree.delete_AABB_tree_Polyhedron_3_Halfedge_handle

# Register AABB_tree_Polyhedron_3_Halfedge_handle in _CGAL_AABB_tree:
_CGAL_AABB_tree.AABB_tree_Polyhedron_3_Halfedge_handle_swigregister(AABB_tree_Polyhedron_3_Halfedge_handle)

class AABB_tree_Segment_3_soup(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_AABB_tree.AABB_tree_Segment_3_soup_swiginit(self, _CGAL_AABB_tree.new_AABB_tree_Segment_3_soup(*args))

    def insert_from_array(self, input):
        return _CGAL_AABB_tree.AABB_tree_Segment_3_soup_insert_from_array(self, input)

    def rebuild(self, range):
        return _CGAL_AABB_tree.AABB_tree_Segment_3_soup_rebuild(self, range)

    def clear(self):
        return _CGAL_AABB_tree.AABB_tree_Segment_3_soup_clear(self)

    def size(self):
        return _CGAL_AABB_tree.AABB_tree_Segment_3_soup_size(self)

    def empty(self):
        return _CGAL_AABB_tree.AABB_tree_Segment_3_soup_empty(self)

    def do_intersect(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Segment_3_soup_do_intersect(self, *args)

    def number_of_intersected_primitives(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Segment_3_soup_number_of_intersected_primitives(self, *args)

    def all_intersected_primitives(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Segment_3_soup_all_intersected_primitives(self, *args)

    def any_intersected_primitive(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Segment_3_soup_any_intersected_primitive(self, *args)

    def any_intersection(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Segment_3_soup_any_intersection(self, *args)

    def all_intersections(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Segment_3_soup_all_intersections(self, *args)

    def squared_distance(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Segment_3_soup_squared_distance(self, *args)

    def closest_point(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Segment_3_soup_closest_point(self, *args)

    def closest_point_and_primitive(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Segment_3_soup_closest_point_and_primitive(self, *args)

    def accelerate_distance_queries(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Segment_3_soup_accelerate_distance_queries(self, *args)
    __swig_destroy__ = _CGAL_AABB_tree.delete_AABB_tree_Segment_3_soup

# Register AABB_tree_Segment_3_soup in _CGAL_AABB_tree:
_CGAL_AABB_tree.AABB_tree_Segment_3_soup_swigregister(AABB_tree_Segment_3_soup)

class AABB_tree_Triangle_3_soup(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_AABB_tree.AABB_tree_Triangle_3_soup_swiginit(self, _CGAL_AABB_tree.new_AABB_tree_Triangle_3_soup(*args))

    def insert_from_array(self, input):
        return _CGAL_AABB_tree.AABB_tree_Triangle_3_soup_insert_from_array(self, input)

    def rebuild(self, range):
        return _CGAL_AABB_tree.AABB_tree_Triangle_3_soup_rebuild(self, range)

    def clear(self):
        return _CGAL_AABB_tree.AABB_tree_Triangle_3_soup_clear(self)

    def size(self):
        return _CGAL_AABB_tree.AABB_tree_Triangle_3_soup_size(self)

    def empty(self):
        return _CGAL_AABB_tree.AABB_tree_Triangle_3_soup_empty(self)

    def do_intersect(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Triangle_3_soup_do_intersect(self, *args)

    def number_of_intersected_primitives(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Triangle_3_soup_number_of_intersected_primitives(self, *args)

    def all_intersected_primitives(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Triangle_3_soup_all_intersected_primitives(self, *args)

    def any_intersected_primitive(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Triangle_3_soup_any_intersected_primitive(self, *args)

    def any_intersection(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Triangle_3_soup_any_intersection(self, *args)

    def all_intersections(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Triangle_3_soup_all_intersections(self, *args)

    def squared_distance(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Triangle_3_soup_squared_distance(self, *args)

    def closest_point(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Triangle_3_soup_closest_point(self, *args)

    def closest_point_and_primitive(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Triangle_3_soup_closest_point_and_primitive(self, *args)

    def accelerate_distance_queries(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Triangle_3_soup_accelerate_distance_queries(self, *args)
    __swig_destroy__ = _CGAL_AABB_tree.delete_AABB_tree_Triangle_3_soup

# Register AABB_tree_Triangle_3_soup in _CGAL_AABB_tree:
_CGAL_AABB_tree.AABB_tree_Triangle_3_soup_swigregister(AABB_tree_Triangle_3_soup)






# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""SWIG wrapper for the CGAL 2D Voronoi Diagram Adaptor package provided under the GPL-3.0+ license"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _CGAL_Voronoi_diagram_2
else:
    import _CGAL_Voronoi_diagram_2

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


import CGAL.CGAL_Kernel
import CGAL.CGAL_Triangulation_2
class Voronoi_diagram_2_Vertex_handle(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_handle_swiginit(self, _CGAL_Voronoi_diagram_2.new_Voronoi_diagram_2_Vertex_handle())

    def halfedge(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_handle_halfedge(self, *args)

    def degree(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_handle_degree(self)

    def point(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_handle_point(self, *args)

    def dual(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_handle_dual(self, *args)

    def site(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_handle_site(self, *args)

    def is_incident_edge(self, c):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_handle_is_incident_edge(self, c)

    def is_incident_face(self, c):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_handle_is_incident_face(self, c)

    def is_valid(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_handle_is_valid(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_handle___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_handle___ne__(self, p)

    def __hash__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_handle___hash__(self)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_handle_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Voronoi_diagram_2_Vertex_handle

# Register Voronoi_diagram_2_Vertex_handle in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_handle_swigregister(Voronoi_diagram_2_Vertex_handle)

class Voronoi_diagram_2_Face_handle(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_handle_swiginit(self, _CGAL_Voronoi_diagram_2.new_Voronoi_diagram_2_Face_handle())

    def halfedge(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_handle_halfedge(self, *args)

    def outer_ccb(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_handle_outer_ccb(self, *args)

    def dual(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_handle_dual(self, *args)

    def is_unbounded(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_handle_is_unbounded(self)

    def is_halfedge_on_ccb(self, c):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_handle_is_halfedge_on_ccb(self, c)

    def is_valid(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_handle_is_valid(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_handle___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_handle___ne__(self, p)

    def __hash__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_handle___hash__(self)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_handle_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Voronoi_diagram_2_Face_handle

# Register Voronoi_diagram_2_Face_handle in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_handle_swigregister(Voronoi_diagram_2_Face_handle)

class Voronoi_diagram_2_Halfedge_handle(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_swiginit(self, _CGAL_Voronoi_diagram_2.new_Voronoi_diagram_2_Halfedge_handle())

    def twin(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_twin(self, *args)

    def opposite(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_opposite(self, *args)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_next(self, *args)

    def previous(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_previous(self, *args)

    def face(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_face(self, *args)

    def source(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_source(self, *args)

    def target(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_target(self, *args)

    def ccb(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_ccb(self, *args)

    def dual(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_dual(self, *args)

    def up(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_up(self, *args)

    def down(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_down(self, *args)

    def left(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_left(self, *args)

    def right(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_right(self, *args)

    def has_source(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_has_source(self)

    def has_target(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_has_target(self)

    def is_unbounded(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_is_unbounded(self)

    def is_bisector(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_is_bisector(self)

    def is_segment(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_is_segment(self)

    def is_ray(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_is_ray(self)

    def is_valid(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_is_valid(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle___ne__(self, p)

    def __hash__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle___hash__(self)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Voronoi_diagram_2_Halfedge_handle

# Register Voronoi_diagram_2_Halfedge_handle in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_handle_swigregister(Voronoi_diagram_2_Halfedge_handle)

class Voronoi_diagram_2_Face_iterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_iterator_swiginit(self, _CGAL_Voronoi_diagram_2.new_Voronoi_diagram_2_Face_iterator())

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Voronoi_diagram_2_Face_iterator

# Register Voronoi_diagram_2_Face_iterator in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Face_iterator_swigregister(Voronoi_diagram_2_Face_iterator)

class Voronoi_diagram_2_Bounded_faces_iterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_faces_iterator_swiginit(self, _CGAL_Voronoi_diagram_2.new_Voronoi_diagram_2_Bounded_faces_iterator())

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_faces_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_faces_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_faces_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_faces_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_faces_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_faces_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_faces_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Voronoi_diagram_2_Bounded_faces_iterator

# Register Voronoi_diagram_2_Bounded_faces_iterator in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_faces_iterator_swigregister(Voronoi_diagram_2_Bounded_faces_iterator)

class Voronoi_diagram_2_Unbounded_faces_iterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_faces_iterator_swiginit(self, _CGAL_Voronoi_diagram_2.new_Voronoi_diagram_2_Unbounded_faces_iterator())

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_faces_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_faces_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_faces_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_faces_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_faces_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_faces_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_faces_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Voronoi_diagram_2_Unbounded_faces_iterator

# Register Voronoi_diagram_2_Unbounded_faces_iterator in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_faces_iterator_swigregister(Voronoi_diagram_2_Unbounded_faces_iterator)

class Voronoi_diagram_2_Edge_iterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Edge_iterator_swiginit(self, _CGAL_Voronoi_diagram_2.new_Voronoi_diagram_2_Edge_iterator())

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Edge_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Edge_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Edge_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Edge_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Edge_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Edge_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Edge_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Voronoi_diagram_2_Edge_iterator

# Register Voronoi_diagram_2_Edge_iterator in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Edge_iterator_swigregister(Voronoi_diagram_2_Edge_iterator)

class Voronoi_diagram_2_Halfedge_iterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_iterator_swiginit(self, _CGAL_Voronoi_diagram_2.new_Voronoi_diagram_2_Halfedge_iterator())

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Voronoi_diagram_2_Halfedge_iterator

# Register Voronoi_diagram_2_Halfedge_iterator in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_iterator_swigregister(Voronoi_diagram_2_Halfedge_iterator)

class Voronoi_diagram_2_Unbounded_halfedges_iterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_halfedges_iterator_swiginit(self, _CGAL_Voronoi_diagram_2.new_Voronoi_diagram_2_Unbounded_halfedges_iterator())

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_halfedges_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_halfedges_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_halfedges_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_halfedges_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_halfedges_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_halfedges_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_halfedges_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Voronoi_diagram_2_Unbounded_halfedges_iterator

# Register Voronoi_diagram_2_Unbounded_halfedges_iterator in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Unbounded_halfedges_iterator_swigregister(Voronoi_diagram_2_Unbounded_halfedges_iterator)

class Voronoi_diagram_2_Bounded_halfedges_iterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_halfedges_iterator_swiginit(self, _CGAL_Voronoi_diagram_2.new_Voronoi_diagram_2_Bounded_halfedges_iterator())

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_halfedges_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_halfedges_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_halfedges_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_halfedges_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_halfedges_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_halfedges_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_halfedges_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Voronoi_diagram_2_Bounded_halfedges_iterator

# Register Voronoi_diagram_2_Bounded_halfedges_iterator in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Bounded_halfedges_iterator_swigregister(Voronoi_diagram_2_Bounded_halfedges_iterator)

class Voronoi_diagram_2_Ccb_halfedge_circulator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Ccb_halfedge_circulator_swiginit(self, _CGAL_Voronoi_diagram_2.new_Voronoi_diagram_2_Ccb_halfedge_circulator())

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Ccb_halfedge_circulator___iter__(self)

    def next(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Ccb_halfedge_circulator_next(self)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Ccb_halfedge_circulator_deepcopy(self, *args)

    def prev(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Ccb_halfedge_circulator_prev(self)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Ccb_halfedge_circulator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Ccb_halfedge_circulator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Ccb_halfedge_circulator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Voronoi_diagram_2_Ccb_halfedge_circulator

# Register Voronoi_diagram_2_Ccb_halfedge_circulator in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Ccb_halfedge_circulator_swigregister(Voronoi_diagram_2_Ccb_halfedge_circulator)

class Voronoi_diagram_2_Halfedge_around_vertex_circulator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_around_vertex_circulator_swiginit(self, _CGAL_Voronoi_diagram_2.new_Voronoi_diagram_2_Halfedge_around_vertex_circulator())

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_around_vertex_circulator___iter__(self)

    def next(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_around_vertex_circulator_next(self)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_around_vertex_circulator_deepcopy(self, *args)

    def prev(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_around_vertex_circulator_prev(self)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_around_vertex_circulator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_around_vertex_circulator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_around_vertex_circulator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Voronoi_diagram_2_Halfedge_around_vertex_circulator

# Register Voronoi_diagram_2_Halfedge_around_vertex_circulator in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Halfedge_around_vertex_circulator_swigregister(Voronoi_diagram_2_Halfedge_around_vertex_circulator)

class Voronoi_diagram_2_Vertex_iterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_iterator_swiginit(self, _CGAL_Voronoi_diagram_2.new_Voronoi_diagram_2_Vertex_iterator())

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Voronoi_diagram_2_Vertex_iterator

# Register Voronoi_diagram_2_Vertex_iterator in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Vertex_iterator_swigregister(Voronoi_diagram_2_Vertex_iterator)

class Voronoi_diagram_2_Site_iterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Site_iterator_swiginit(self, _CGAL_Voronoi_diagram_2.new_Voronoi_diagram_2_Site_iterator())

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Site_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Site_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Site_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Site_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Site_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Site_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Site_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Voronoi_diagram_2_Site_iterator

# Register Voronoi_diagram_2_Site_iterator in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Site_iterator_swigregister(Voronoi_diagram_2_Site_iterator)

class Voronoi_diagram_2_Locate_result(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Locate_result_swiginit(self, _CGAL_Voronoi_diagram_2.new_Voronoi_diagram_2_Locate_result())

    def get_vertex_handle(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Locate_result_get_vertex_handle(self)

    def get_halfedge_handle(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Locate_result_get_halfedge_handle(self)

    def get_face_handle(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Locate_result_get_face_handle(self)

    def is_vertex_handle(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Locate_result_is_vertex_handle(self)

    def is_halfedge_handle(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Locate_result_is_halfedge_handle(self)

    def is_face_handle(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Locate_result_is_face_handle(self)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Voronoi_diagram_2_Locate_result

# Register Voronoi_diagram_2_Locate_result in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Voronoi_diagram_2_Locate_result_swigregister(Voronoi_diagram_2_Locate_result)

class Voronoi_diagram_2(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_swiginit(self, _CGAL_Voronoi_diagram_2.new_Voronoi_diagram_2(*args))

    def insert(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_insert(self, *args)

    def dual(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_dual(self, *args)

    def number_of_vertices(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_number_of_vertices(self)

    def number_of_faces(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_number_of_faces(self)

    def number_of_halfedges(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_number_of_halfedges(self)

    def number_of_connected_components(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_number_of_connected_components(self)

    def unbounded_face(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_unbounded_face(self, *args)

    def bounded_face(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_bounded_face(self, *args)

    def unbounded_halfedge(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_unbounded_halfedge(self, *args)

    def bounded_halfedge(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_bounded_halfedge(self, *args)

    def is_valid(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_is_valid(self)

    def clear(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_clear(self)

    def swap(self, other):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_swap(self, other)

    def file_output(self, fname):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_file_output(self, fname)

    def file_input(self, fname):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_file_input(self, fname)

    def faces(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_faces(self)

    def unbounded_faces(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_unbounded_faces(self)

    def bounded_faces(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_bounded_faces(self)

    def edges(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_edges(self)

    def halfedges(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_halfedges(self)

    def unbounded_halfedges(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_unbounded_halfedges(self)

    def bounded_halfedges(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_bounded_halfedges(self)

    def vertices(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_vertices(self)

    def sites(self):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_sites(self)

    def ccb_halfedges(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_ccb_halfedges(self, *args)

    def incident_halfedges(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_incident_halfedges(self, *args)

    def locate(self, *args):
        return _CGAL_Voronoi_diagram_2.Voronoi_diagram_2_locate(self, *args)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Voronoi_diagram_2

# Register Voronoi_diagram_2 in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Voronoi_diagram_2_swigregister(Voronoi_diagram_2)

class Power_diagram_2_Vertex_handle(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_handle_swiginit(self, _CGAL_Voronoi_diagram_2.new_Power_diagram_2_Vertex_handle())

    def halfedge(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_handle_halfedge(self, *args)

    def degree(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_handle_degree(self)

    def point(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_handle_point(self, *args)

    def dual(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_handle_dual(self, *args)

    def site(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_handle_site(self, *args)

    def is_incident_edge(self, c):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_handle_is_incident_edge(self, c)

    def is_incident_face(self, c):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_handle_is_incident_face(self, c)

    def is_valid(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_handle_is_valid(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_handle___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_handle___ne__(self, p)

    def __hash__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_handle___hash__(self)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_handle_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Power_diagram_2_Vertex_handle

# Register Power_diagram_2_Vertex_handle in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_handle_swigregister(Power_diagram_2_Vertex_handle)

class Power_diagram_2_Face_handle(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_handle_swiginit(self, _CGAL_Voronoi_diagram_2.new_Power_diagram_2_Face_handle())

    def halfedge(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_handle_halfedge(self, *args)

    def outer_ccb(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_handle_outer_ccb(self, *args)

    def dual(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_handle_dual(self, *args)

    def is_unbounded(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_handle_is_unbounded(self)

    def is_halfedge_on_ccb(self, c):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_handle_is_halfedge_on_ccb(self, c)

    def is_valid(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_handle_is_valid(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_handle___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_handle___ne__(self, p)

    def __hash__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_handle___hash__(self)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_handle_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Power_diagram_2_Face_handle

# Register Power_diagram_2_Face_handle in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Power_diagram_2_Face_handle_swigregister(Power_diagram_2_Face_handle)

class Power_diagram_2_Halfedge_handle(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_swiginit(self, _CGAL_Voronoi_diagram_2.new_Power_diagram_2_Halfedge_handle())

    def twin(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_twin(self, *args)

    def opposite(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_opposite(self, *args)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_next(self, *args)

    def previous(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_previous(self, *args)

    def face(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_face(self, *args)

    def source(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_source(self, *args)

    def target(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_target(self, *args)

    def ccb(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_ccb(self, *args)

    def dual(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_dual(self, *args)

    def up(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_up(self, *args)

    def down(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_down(self, *args)

    def left(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_left(self, *args)

    def right(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_right(self, *args)

    def has_source(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_has_source(self)

    def has_target(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_has_target(self)

    def is_unbounded(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_is_unbounded(self)

    def is_bisector(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_is_bisector(self)

    def is_segment(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_is_segment(self)

    def is_ray(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_is_ray(self)

    def is_valid(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_is_valid(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle___ne__(self, p)

    def __hash__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle___hash__(self)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Power_diagram_2_Halfedge_handle

# Register Power_diagram_2_Halfedge_handle in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_handle_swigregister(Power_diagram_2_Halfedge_handle)

class Power_diagram_2_Face_iterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_iterator_swiginit(self, _CGAL_Voronoi_diagram_2.new_Power_diagram_2_Face_iterator())

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Face_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Power_diagram_2_Face_iterator

# Register Power_diagram_2_Face_iterator in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Power_diagram_2_Face_iterator_swigregister(Power_diagram_2_Face_iterator)

class Power_diagram_2_Bounded_faces_iterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_faces_iterator_swiginit(self, _CGAL_Voronoi_diagram_2.new_Power_diagram_2_Bounded_faces_iterator())

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_faces_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_faces_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_faces_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_faces_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_faces_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_faces_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_faces_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Power_diagram_2_Bounded_faces_iterator

# Register Power_diagram_2_Bounded_faces_iterator in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_faces_iterator_swigregister(Power_diagram_2_Bounded_faces_iterator)

class Power_diagram_2_Unbounded_faces_iterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_faces_iterator_swiginit(self, _CGAL_Voronoi_diagram_2.new_Power_diagram_2_Unbounded_faces_iterator())

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_faces_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_faces_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_faces_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_faces_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_faces_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_faces_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_faces_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Power_diagram_2_Unbounded_faces_iterator

# Register Power_diagram_2_Unbounded_faces_iterator in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_faces_iterator_swigregister(Power_diagram_2_Unbounded_faces_iterator)

class Power_diagram_2_Edge_iterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Power_diagram_2_Edge_iterator_swiginit(self, _CGAL_Voronoi_diagram_2.new_Power_diagram_2_Edge_iterator())

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Edge_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Edge_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Edge_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Edge_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Edge_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Edge_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Edge_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Power_diagram_2_Edge_iterator

# Register Power_diagram_2_Edge_iterator in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Power_diagram_2_Edge_iterator_swigregister(Power_diagram_2_Edge_iterator)

class Power_diagram_2_Halfedge_iterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_iterator_swiginit(self, _CGAL_Voronoi_diagram_2.new_Power_diagram_2_Halfedge_iterator())

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Power_diagram_2_Halfedge_iterator

# Register Power_diagram_2_Halfedge_iterator in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_iterator_swigregister(Power_diagram_2_Halfedge_iterator)

class Power_diagram_2_Unbounded_halfedges_iterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_halfedges_iterator_swiginit(self, _CGAL_Voronoi_diagram_2.new_Power_diagram_2_Unbounded_halfedges_iterator())

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_halfedges_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_halfedges_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_halfedges_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_halfedges_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_halfedges_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_halfedges_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_halfedges_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Power_diagram_2_Unbounded_halfedges_iterator

# Register Power_diagram_2_Unbounded_halfedges_iterator in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Power_diagram_2_Unbounded_halfedges_iterator_swigregister(Power_diagram_2_Unbounded_halfedges_iterator)

class Power_diagram_2_Bounded_halfedges_iterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_halfedges_iterator_swiginit(self, _CGAL_Voronoi_diagram_2.new_Power_diagram_2_Bounded_halfedges_iterator())

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_halfedges_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_halfedges_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_halfedges_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_halfedges_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_halfedges_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_halfedges_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_halfedges_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Power_diagram_2_Bounded_halfedges_iterator

# Register Power_diagram_2_Bounded_halfedges_iterator in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Power_diagram_2_Bounded_halfedges_iterator_swigregister(Power_diagram_2_Bounded_halfedges_iterator)

class Power_diagram_2_Ccb_halfedge_circulator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Power_diagram_2_Ccb_halfedge_circulator_swiginit(self, _CGAL_Voronoi_diagram_2.new_Power_diagram_2_Ccb_halfedge_circulator())

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Ccb_halfedge_circulator___iter__(self)

    def next(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Ccb_halfedge_circulator_next(self)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Ccb_halfedge_circulator_deepcopy(self, *args)

    def prev(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Ccb_halfedge_circulator_prev(self)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Ccb_halfedge_circulator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Ccb_halfedge_circulator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Ccb_halfedge_circulator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Power_diagram_2_Ccb_halfedge_circulator

# Register Power_diagram_2_Ccb_halfedge_circulator in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Power_diagram_2_Ccb_halfedge_circulator_swigregister(Power_diagram_2_Ccb_halfedge_circulator)

class Power_diagram_2_Halfedge_around_vertex_circulator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_around_vertex_circulator_swiginit(self, _CGAL_Voronoi_diagram_2.new_Power_diagram_2_Halfedge_around_vertex_circulator())

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_around_vertex_circulator___iter__(self)

    def next(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_around_vertex_circulator_next(self)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_around_vertex_circulator_deepcopy(self, *args)

    def prev(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_around_vertex_circulator_prev(self)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_around_vertex_circulator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_around_vertex_circulator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_around_vertex_circulator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Power_diagram_2_Halfedge_around_vertex_circulator

# Register Power_diagram_2_Halfedge_around_vertex_circulator in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Power_diagram_2_Halfedge_around_vertex_circulator_swigregister(Power_diagram_2_Halfedge_around_vertex_circulator)

class Power_diagram_2_Vertex_iterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_iterator_swiginit(self, _CGAL_Voronoi_diagram_2.new_Power_diagram_2_Vertex_iterator())

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Power_diagram_2_Vertex_iterator

# Register Power_diagram_2_Vertex_iterator in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Power_diagram_2_Vertex_iterator_swigregister(Power_diagram_2_Vertex_iterator)

class Power_diagram_2_Site_iterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Power_diagram_2_Site_iterator_swiginit(self, _CGAL_Voronoi_diagram_2.new_Power_diagram_2_Site_iterator())

    def __iter__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Site_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Site_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Site_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Site_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Site_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Site_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Site_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Power_diagram_2_Site_iterator

# Register Power_diagram_2_Site_iterator in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Power_diagram_2_Site_iterator_swigregister(Power_diagram_2_Site_iterator)

class Power_diagram_2_Locate_result(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Power_diagram_2_Locate_result_swiginit(self, _CGAL_Voronoi_diagram_2.new_Power_diagram_2_Locate_result())

    def get_vertex_handle(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Locate_result_get_vertex_handle(self)

    def get_halfedge_handle(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Locate_result_get_halfedge_handle(self)

    def get_face_handle(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Locate_result_get_face_handle(self)

    def is_vertex_handle(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Locate_result_is_vertex_handle(self)

    def is_halfedge_handle(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Locate_result_is_halfedge_handle(self)

    def is_face_handle(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_Locate_result_is_face_handle(self)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Power_diagram_2_Locate_result

# Register Power_diagram_2_Locate_result in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Power_diagram_2_Locate_result_swigregister(Power_diagram_2_Locate_result)

class Power_diagram_2(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _CGAL_Voronoi_diagram_2.Power_diagram_2_swiginit(self, _CGAL_Voronoi_diagram_2.new_Power_diagram_2(*args))

    def insert(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_insert(self, *args)

    def dual(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_dual(self, *args)

    def number_of_vertices(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_number_of_vertices(self)

    def number_of_faces(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_number_of_faces(self)

    def number_of_halfedges(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_number_of_halfedges(self)

    def number_of_connected_components(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_number_of_connected_components(self)

    def unbounded_face(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_unbounded_face(self, *args)

    def bounded_face(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_bounded_face(self, *args)

    def unbounded_halfedge(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_unbounded_halfedge(self, *args)

    def bounded_halfedge(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_bounded_halfedge(self, *args)

    def is_valid(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_is_valid(self)

    def clear(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_clear(self)

    def swap(self, other):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_swap(self, other)

    def file_output(self, fname):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_file_output(self, fname)

    def file_input(self, fname):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_file_input(self, fname)

    def faces(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_faces(self)

    def unbounded_faces(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_unbounded_faces(self)

    def bounded_faces(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_bounded_faces(self)

    def edges(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_edges(self)

    def halfedges(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_halfedges(self)

    def unbounded_halfedges(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_unbounded_halfedges(self)

    def bounded_halfedges(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_bounded_halfedges(self)

    def vertices(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_vertices(self)

    def sites(self):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_sites(self)

    def ccb_halfedges(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_ccb_halfedges(self, *args)

    def incident_halfedges(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_incident_halfedges(self, *args)

    def locate(self, *args):
        return _CGAL_Voronoi_diagram_2.Power_diagram_2_locate(self, *args)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Power_diagram_2

# Register Power_diagram_2 in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Power_diagram_2_swigregister(Power_diagram_2)


def crop_voronoi_facet(arg1, arg2, arg3, arg4):
    return _CGAL_Voronoi_diagram_2.crop_voronoi_facet(arg1, arg2, arg3, arg4)
class Optional_segment_2(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        _CGAL_Voronoi_diagram_2.Optional_segment_2_swiginit(self, _CGAL_Voronoi_diagram_2.new_Optional_segment_2())

    def empty(self):
        return _CGAL_Voronoi_diagram_2.Optional_segment_2_empty(self)

    def value(self):
        return _CGAL_Voronoi_diagram_2.Optional_segment_2_value(self)

    def deepcopy(self, *args):
        return _CGAL_Voronoi_diagram_2.Optional_segment_2_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_Voronoi_diagram_2.delete_Optional_segment_2

# Register Optional_segment_2 in _CGAL_Voronoi_diagram_2:
_CGAL_Voronoi_diagram_2.Optional_segment_2_swigregister(Optional_segment_2)


def crop_voronoi_facet_polygon(arg1, arg2, arg3, arg4):
    return _CGAL_Voronoi_diagram_2.crop_voronoi_facet_polygon(arg1, arg2, arg3, arg4)

def crop_voronoi_edge(arg1, arg2, arg3):
    return _CGAL_Voronoi_diagram_2.crop_voronoi_edge(arg1, arg2, arg3)


